# TODO:
1. This
1. non-playsound osx
1. HTTP command receiver (lioran!)
1. custom hook code - lioran example? obs websocket?
1. more flexible command triggers (regex??)
1. verify file exists before queueing sound?
1. add artifact upload to pipleine for non-release builds
1. windows internal files not found?